particle-tracking-manager
==============================
[![Build Status](https://img.shields.io/github/actions/workflow/status/axiom-data-science/particle-tracking-manager/test.yaml?branch=main&logo=github&style=for-the-badge)](https://github.com/axiom-data-science/particle-tracking-manager/actions)
[![Code Coverage](https://img.shields.io/codecov/c/github/axiom-data-science/particle-tracking-manager.svg?style=for-the-badge)](https://codecov.io/gh/axiom-data-science/particle-tracking-manager)
[![License:MIT](https://img.shields.io/badge/License-MIT-green.svg?style=for-the-badge)](https://opensource.org/licenses/MIT)
[![Documentation Status](https://img.shields.io/readthedocs/particle-tracking-manager/latest.svg?style=for-the-badge)](https://particle-tracking-manager.readthedocs.io/en/latest/?badge=latest)
[![Code Style Status](https://img.shields.io/github/actions/workflow/status/axiom-data-science/particle-tracking-manager/pre-commit.yml?branch-main&label=Code%20Style&style=for-the-badge)](https://github.com/axiom-data-science/particle-tracking-manager/actions)
[![Conda Version](https://img.shields.io/conda/vn/conda-forge/particle-tracking-manager.svg?style=for-the-badge)](https://anaconda.org/conda-forge/particle-tracking-manager)
[![Python Package Index](https://img.shields.io/pypi/v/particle-tracking-manager.svg?style=for-the-badge)](https://pypi.org/project/particle-tracking-manager)


Manager for particle tracking simulations.

--------

<p><small>Project based on the <a target="_blank" href="https://github.com/jbusecke/cookiecutter-science-project">cookiecutter science project template</a>.</small></p>


# Installation

Install with

    pip install particle-tracking-manager

or

    conda install -c conda-forge particle-tracking-manager

To install environment from github repo after cloning repo:

    conda env create -f environment.yml

To install packages to run pre-commit:

    mamba install --file requirements-dev.txt
